@@ -12,10 +12,10 @@ os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.settings')
 from dotenv import load_dotenv
 # explicitly providing path to '.env'
 from pathlib import Path  # python3 only
-env_path = Path('.') / '.crm'
+env_path = Path('~') / '.crm'
 load_dotenv(dotenv_path=env_path)
 
-os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
+os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION', 'Development').capitalize())
 
 
 # os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.dev_settings')
