@@ -307,9 +307,13 @@ class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurat
         if self.STORAGE_TYPE == 's3':
             return [str(self.BASE_DIR) + '/static']
         else:
-            return values.ListValue(default=[
-                os.path.join(self.BASE_DIR, 'frontend'),
-            ], environ_name='STATICFILES_DIRS', environ_prefix='KRYNEGGER')
+            return values.ListValue(
+                default=[
+                    os.path.join(self.BASE_DIR, 'frontend'),
+                ],
+                environ_name='STATICFILES_DIRS',
+                environ_prefix='KRYNEGGER'
+            )
 
     STATICFILES_FINDERS = [
         'django.contrib.staticfiles.finders.FileSystemFinder',
@@ -322,8 +326,11 @@ class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurat
         if self.STORAGE_TYPE == 's3':
             return '/%s/' % self.DEFAULT_S3_PATH
         else:
-            return values.PathValue(default=os.path.join(self.BASE_DIR, 'media'), environ_name='MEDIA_ROOT',
-                                    environ_prefix='KRYNEGGER')
+            return values.PathValue(
+                default=os.path.join(self.BASE_DIR, 'media'),
+                environ_name='MEDIA_ROOT',
+                environ_prefix='KRYNEGGER'
+            )
 
     @property
     def MEDIA_URL(self) -> str:
